
/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) INRIA - Allan CORNET
* 
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at    
* http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
*
*/

/*--------------------------------------------------------------------------*/
#ifndef __BUILDMAINWINDOWTITLE_WINDOWS_H__
#define __BUILDMAINWINDOWTITLE_WINDOWS_H__

#include "dynlib_scilab_windows.h"

/**
* build title of the main scilab window (Windows)
* @return string (title)
*/
SCILAB_WINDOWS_IMPEXP char *buildMainWindowTitle_Windows(void);

#endif /* __BUILDMAINWINDOWTITLE_WINDOWS_H__ */
/*--------------------------------------------------------------------------*/
